@@ -21,8 +21,8 @@ class ChainSpec:
     def from_chain_str(s):
         (chain_name, chain_id) = s.split(':')
         return ChainSpec({
-            'param': {
-                'networkID': chain_id,
+            'params': {
+                'networkID': int(chain_id),
                 },
             'name': chain_name,
             }
